/*
* OpenGLScene.h 
* An interface render the Qt- Graphicsview - OpenGL window
* 
* Copyright (c) Brian Gee Chacko, 2010
* M.S.Ramaiah School of Advanced Studies, Bangalore 
*/

#ifndef OPENGL_SCENE_H
#define OPENGL_SCENE_H

#ifndef QT_NO_CONCURRENT
#include <QFutureWatcher>
#endif

#include "ScoreUI.h"
#include "Stopwatch.h"
#include "ImageWidget.h"

#include <QLabel>
#include <QTime>
#include <QGraphicsScene>

#include <QtOpenGL>

struct OpenGLSceneData;
class OpenGLScene : public QGraphicsScene
{
	Q_OBJECT

public:
	OpenGLScene();
    ~OpenGLScene();

public slots:
	void advanceTarget();
	void advanceProjectile();
	void updateUITopScore();

protected:
	bool populateSceneAttribs();
	void setPreDefSceneAttribPositions();

	ScoreUI* createScoringWidget(); 
	QWidget* createStopWatchWidget();
	QDialog* createDialog(const QString& windowTitle) const;
	QWidget* createWidget(const QString& windowTitle) const;
	QWidget* createImageWidget(const QString& filename);

	void drawBackground(QPainter* painter, const QRectF &rect);

	void mousePressEvent(QGraphicsSceneMouseEvent* event);
	void mouseReleaseEvent(QGraphicsSceneMouseEvent* event);
	void mouseMoveEvent(QGraphicsSceneMouseEvent* event);

signals:
	void collided();

private:
	OpenGLSceneData* d;
	
	QList<QGraphicsItem*> m_sceneItems;
	QMap<QString, QGraphicsItem*> m_sceneAttribs;
	QString m_fileName;
	GLuint m_textures[5];
	QString m_topScore;
	QString m_yourScore;

	ScoreUI* m_score;
	Stopwatch* m_stopWatch;
	ImageWidget* m_imageWidget;
	QWidget* m_smileOrAngry;
};

#endif // OPENGL_SCENE_H

